@@ -32,12 +32,15 @@ class Course : public CourseBase
     Q_OBJECT
     Q_PROPERTY(DataIndexCourse* associatedDataIndexCourse READ associatedDataIndexCourse WRITE setAssociatedDataIndexCourse NOTIFY associatedDataIndexCourseChanged)
     Q_PROPERTY(int lessonCount READ lessonCount NOTIFY lessonCountChanged)
+    Q_PROPERTY(bool doSyncLessonCharacters READ doSyncLessonCharacters WRITE setDoSyncLessonCharacters NOTIFY doSyncLessonCharactersChanged)
 
 public:
     explicit Course(QObject *parent = 0);
     DataIndexCourse* associatedDataIndexCourse() const;
     void setAssociatedDataIndexCourse(DataIndexCourse* dataIndexCourse);
     int lessonCount() const;
+    bool doSyncLessonCharacters() const;
+    void setDoSyncLessonCharacters(bool doSync);
     void setId(const QString& id);
     void setTitle(const QString& title);
     void setDescription(const QString& description);
@@ -52,6 +55,7 @@ public:
 signals:
     void associatedDataIndexCourseChanged();
     void lessonCountChanged();
+    void doSyncLessonCharactersChanged();
     void lessonAboutToBeAdded(Lesson* lesson, int index);
     void lessonAdded();
     void lessonsAboutToBeRemoved(int first, int last);
@@ -63,6 +67,7 @@ private slots:
 private:
     Q_DISABLE_COPY(Course)
     DataIndexCourse* m_associatedDataIndexCourse;
+    bool m_doSyncLessonCharacters;
     QList<Lesson*> m_lessons;
     QSignalMapper* m_signalMapper;
 };
